@@ -670,6 +670,10 @@ fn incoming_fixtures() {
                 assert_eq!(result.genesis.validators[0].power(), 10);
                 assert!(result.genesis.validators[0].pub_key.ed25519().is_some());
                 assert_eq!(result.genesis.validators[0].proposer_priority.value(), 0);
+                assert_eq!(
+                    result.genesis.consensus_params.block.time_iota_ms,
+                    tendermint::block::Size::default_time_iota_ms(),
+                );
             }
             "net_info" => {
                 let result = endpoint::net_info::Response::from_string(content).unwrap();
@@ -703,7 +707,7 @@ fn incoming_fixtures() {
                         app: 1
                     }
                 );
-                assert_eq!(result.node_info.version.to_string(), "v0.34.0");
+                assert_eq!(result.node_info.version.to_string(), "v0.34.9");
                 assert!(!result.sync_info.catching_up);
                 assert_eq!(result.sync_info.latest_app_hash.value(), [0; 8]);
                 assert!(!result.sync_info.latest_block_hash.is_empty());
@@ -717,7 +721,7 @@ fn incoming_fixtures() {
                         > 0
                 );
                 assert!(result.validator_info.pub_key.ed25519().is_some());
-                assert_eq!(result.validator_info.voting_power.value(), 10);
+                assert_eq!(result.validator_info.power.value(), 10);
             }
             "subscribe_malformed" => {
                 let result = endpoint::subscribe::Response::from_string(content)
@@ -1025,14 +1029,18 @@ fn incoming_fixtures() {
                     assert!(tx_result.result.gas_wanted.is_none());
                     assert!(tx_result.result.gas_used.is_none());
                     assert_eq!(tx_result.result.events.len(), 1);
-                    assert_eq!(tx_result.result.events[0].event_type, "app");
+                    assert_eq!(tx_result.result.events[0].type_str, "app");
                     for attr in &tx_result.result.events[0].attributes {
-                        match attr.key.as_str() {
-                            "Y3JlYXRvcg==" => assert_eq!(attr.value, "Q29zbW9zaGkgTmV0b3dva28="),
-                            "a2V5" => assert_eq!(attr.value, "dHgw"),
-                            "aW5kZXhfa2V5" => assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw=="),
-                            "bm9pbmRleF9rZXk=" => {
-                                assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw==")
+                        match attr.key.as_ref() {
+                            "creator" => {
+                                assert_eq!(attr.value.as_ref(), "Cosmoshi Netowoko")
+                            }
+                            "key" => assert_eq!(attr.value.as_ref(), "tx0"),
+                            "index_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
+                            }
+                            "noindex_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
                             }
                             _ => panic!("unknown attribute found {}", attr.key),
                         }
@@ -1065,14 +1073,18 @@ fn incoming_fixtures() {
                     assert!(tx_result.result.gas_wanted.is_none());
                     assert!(tx_result.result.gas_used.is_none());
                     assert_eq!(tx_result.result.events.len(), 1);
-                    assert_eq!(tx_result.result.events[0].event_type, "app");
+                    assert_eq!(tx_result.result.events[0].type_str, "app");
                     for attr in &tx_result.result.events[0].attributes {
-                        match attr.key.as_str() {
-                            "Y3JlYXRvcg==" => assert_eq!(attr.value, "Q29zbW9zaGkgTmV0b3dva28="),
-                            "a2V5" => assert_eq!(attr.value, "dHgx"),
-                            "aW5kZXhfa2V5" => assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw=="),
-                            "bm9pbmRleF9rZXk=" => {
-                                assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw==")
+                        match attr.key.as_ref() {
+                            "creator" => {
+                                assert_eq!(attr.value.as_ref(), "Cosmoshi Netowoko")
+                            }
+                            "key" => assert_eq!(attr.value.as_ref(), "tx1"),
+                            "index_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
+                            }
+                            "noindex_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
                             }
                             _ => panic!("unknown attribute found {}", attr.key),
                         }
@@ -1105,14 +1117,18 @@ fn incoming_fixtures() {
                     assert!(tx_result.result.gas_wanted.is_none());
                     assert!(tx_result.result.gas_used.is_none());
                     assert_eq!(tx_result.result.events.len(), 1);
-                    assert_eq!(tx_result.result.events[0].event_type, "app");
+                    assert_eq!(tx_result.result.events[0].type_str, "app");
                     for attr in &tx_result.result.events[0].attributes {
-                        match attr.key.as_str() {
-                            "Y3JlYXRvcg==" => assert_eq!(attr.value, "Q29zbW9zaGkgTmV0b3dva28="),
-                            "a2V5" => assert_eq!(attr.value, "dHgy"),
-                            "aW5kZXhfa2V5" => assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw=="),
-                            "bm9pbmRleF9rZXk=" => {
-                                assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw==")
+                        match attr.key.as_ref() {
+                            "creator" => {
+                                assert_eq!(attr.value.as_ref(), "Cosmoshi Netowoko")
+                            }
+                            "key" => assert_eq!(attr.value.as_ref(), "tx2"),
+                            "index_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
+                            }
+                            "noindex_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
                             }
                             _ => panic!("unknown attribute found {}", attr.key),
                         }
@@ -1145,14 +1161,18 @@ fn incoming_fixtures() {
                     assert!(tx_result.result.gas_wanted.is_none());
                     assert!(tx_result.result.gas_used.is_none());
                     assert_eq!(tx_result.result.events.len(), 1);
-                    assert_eq!(tx_result.result.events[0].event_type, "app");
+                    assert_eq!(tx_result.result.events[0].type_str, "app");
                     for attr in &tx_result.result.events[0].attributes {
-                        match attr.key.as_str() {
-                            "Y3JlYXRvcg==" => assert_eq!(attr.value, "Q29zbW9zaGkgTmV0b3dva28="),
-                            "a2V5" => assert_eq!(attr.value, "dHgz"),
-                            "aW5kZXhfa2V5" => assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw=="),
-                            "bm9pbmRleF9rZXk=" => {
-                                assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw==")
+                        match attr.key.as_ref() {
+                            "creator" => {
+                                assert_eq!(attr.value.as_ref(), "Cosmoshi Netowoko")
+                            }
+                            "key" => assert_eq!(attr.value.as_ref(), "tx3"),
+                            "index_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
+                            }
+                            "noindex_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
                             }
                             _ => panic!("unknown attribute found {}", attr.key),
                         }
@@ -1185,14 +1205,18 @@ fn incoming_fixtures() {
                     assert!(tx_result.result.gas_wanted.is_none());
                     assert!(tx_result.result.gas_used.is_none());
                     assert_eq!(tx_result.result.events.len(), 1);
-                    assert_eq!(tx_result.result.events[0].event_type, "app");
+                    assert_eq!(tx_result.result.events[0].type_str, "app");
                     for attr in &tx_result.result.events[0].attributes {
-                        match attr.key.as_str() {
-                            "Y3JlYXRvcg==" => assert_eq!(attr.value, "Q29zbW9zaGkgTmV0b3dva28="),
-                            "a2V5" => assert_eq!(attr.value, "dHg0"),
-                            "aW5kZXhfa2V5" => assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw=="),
-                            "bm9pbmRleF9rZXk=" => {
-                                assert_eq!(attr.value, "aW5kZXggaXMgd29ya2luZw==")
+                        match attr.key.as_ref() {
+                            "creator" => {
+                                assert_eq!(attr.value.as_ref(), "Cosmoshi Netowoko")
+                            }
+                            "key" => assert_eq!(attr.value.as_ref(), "tx4"),
+                            "index_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
+                            }
+                            "noindex_key" => {
+                                assert_eq!(attr.value.as_ref(), "index is working")
                             }
                             _ => panic!("unknown attribute found {}", attr.key),
                         }
